@@ -37,3 +37,8 @@ class NotFoundException(SdkException):
 class InternalServerErrorException(SdkException):
 
     status_code = 5001
+
+
+class TimeoutException(SdkException):
+
+    status_code = 5041
